@@ -11,7 +11,7 @@ package CP932IBM::R2;
 use 5.00503;    # Galapagos Consensus 1998 for primetools
 # use 5.008001; # Lancaster Consensus 2013 for toolchains
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 $VERSION = $VERSION;
 
 use strict;
@@ -102,7 +102,7 @@ These subroutines provide CP932IBM octets semantics for you.
   Acts as SBCS             Acts as MBCS
   Octet in Script          Octet of I/O Encoding                       Note and Limitations
   ------------------------------------------------------------------------------------------------------------------------------------------
-  getc                     ioget(FILEHANDLE)                           get UTF-8 codepoint octets from CP932IBM file
+  <FILEHANDLE>             ioget(FILEHANDLE)                           get UTF-8 codepoint octets from CP932IBM file
   ------------------------------------------------------------------------------------------------------------------------------------------
   length                   iolen($utf8str)                             octet count of UTF-8 string as CP932IBM encoding
   ------------------------------------------------------------------------------------------------------------------------------------------
